PCB Environment: StepLock Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
StepLock Class Reference

## Public Member Functions
| StepLock (uint granularity=0)
void | setGranularity (uint n)
uint | getGranularity () const
void | wait (uint granularity=1)
void | signal ()

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UI/LockStep.hpp